diff mbox series

aio-dio-regress: code clarification

Message ID 20190805224929.25005-1-agruenba@redhat.com (mailing list archive)
State New, archived
Headers show
Series aio-dio-regress: code clarification | expand

Commit Message

Andreas Gruenbacher Aug. 5, 2019, 10:49 p.m. UTC
In this test, FILE_SIZE is defined as 300 but that definition isn't used
consistently.  Make the code more obvious.

(Used by generic/210.)

Signed-off-by: Andreas Gruenbacher <agruenba@redhat.com>
---
 src/aio-dio-regress/aio-dio-subblock-eof-read.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff mbox series

Patch

diff --git a/src/aio-dio-regress/aio-dio-subblock-eof-read.c b/src/aio-dio-regress/aio-dio-subblock-eof-read.c
index 6f35b0e8..894965ea 100644
--- a/src/aio-dio-regress/aio-dio-subblock-eof-read.c
+++ b/src/aio-dio-regress/aio-dio-subblock-eof-read.c
@@ -63,7 +63,7 @@  main(int argc, char **argv)
 	/* <1> use normal disk read, this should be ok */
 	ret = read(fd, buffer, 4096);
 	if (ret != FILE_SIZE)
-		fail("buffered read returned %d, should be 300\n", ret);
+		fail("buffered read returned %d, should be %d\n", ret, FILE_SIZE);
 
 	/* <2> use AIO disk read, it sees error. */
 	memset(&myiocb, 0, sizeof(myiocb));
@@ -89,7 +89,7 @@  main(int argc, char **argv)
 		fail("io_getevents returned %d\n", ret);
 
 	/*
 	 *  If all goes well, we should see 300 bytes read.  If things
 	 *  are broken, we may very well see a result of 4k.
 	 */
 	if (ie.res != FILE_SIZE)
@@ -89,7 +89,7 @@  main(int argc, char **argv)
 
 	/*
-	 *  If all goes well, we should see 300 bytes read.  If things
+	 *  If all goes well, we should see FILE_SIZE bytes read.  If things
 	 *  are broken, we may very well see a result of 4k.
 	 */